@@ -47,6 +47,7 @@ from .clinvar import ClinVarHandler
 from .matchmaker import MMEHandler
 from .filter import FilterHandler
 from .cytoband import CytobandHandler
+from .managed_variant import ManagedVariantHandler
 
 log = logging.getLogger(__name__)
 
@@ -68,6 +69,7 @@ class MongoAdapter(
     MMEHandler,
     TranscriptHandler,
     FilterHandler,
+    ManagedVariantHandler,
     CytobandHandler,
 ):
 
@@ -104,6 +106,7 @@ class MongoAdapter(
         self.transcript_collection = database.transcript
         self.filter_collection = database.filter
         self.cytoband_collection = database.cytoband
+        self.managed_variant_collection = database.managed_variant
 
     def collections(self):
         """Return all collection names
