@@ -19,9 +19,7 @@ LOG = logging.getLogger(__name__)
 
 
 @click.command("case", short_help="Load a case")
-@click.option(
-    "--vcf", type=click.Path(exists=True), help="path to clinical VCF file to be loaded"
-)
+@click.option("--vcf", type=click.Path(exists=True), help="path to clinical VCF file to be loaded")
 @click.option(
     "--vcf-sv",
     type=click.Path(exists=True),
@@ -52,15 +50,9 @@ LOG = logging.getLogger(__name__)
 )
 @click.option("--no-variants", is_flag=False)
 @click.argument("config", type=click.File("r"), required=False)
-@click.option(
-    "--peddy-ped", type=click.Path(exists=True), help="path to a peddy.ped file"
-)
-@click.option(
-    "--peddy-sex", type=click.Path(exists=True), help="path to a sex_check.csv file"
-)
-@click.option(
-    "--peddy-check", type=click.Path(exists=True), help="path to a ped_check.csv file"
-)
+@click.option("--peddy-ped", type=click.Path(exists=True), help="path to a peddy.ped file")
+@click.option("--peddy-sex", type=click.Path(exists=True), help="path to a sex_check.csv file")
+@click.option("--peddy-check", type=click.Path(exists=True), help="path to a ped_check.csv file")
 @with_appcontext
 def case(
     vcf,
