@@ -23,7 +23,10 @@ LOG = logging.getLogger(__name__)
 
 
 def load_hpo(
-    adapter, disease_lines=None, hpo_lines=None, hpo_gene_lines=None,
+    adapter,
+    disease_lines=None,
+    hpo_lines=None,
+    hpo_gene_lines=None,
 ):
     """Load the hpo terms and hpo diseases into database
 
@@ -115,9 +118,7 @@ def load_hpo_terms(adapter, hpo_lines=None, hpo_gene_lines=None, alias_genes=Non
     LOG.info("Loading the hpo terms...")
     nr_terms = len(hpo_terms)
     hpo_bulk = []
-    with progressbar(
-        hpo_terms.values(), label="Loading hpo terms", length=nr_terms
-    ) as bar:
+    with progressbar(hpo_terms.values(), label="Loading hpo terms", length=nr_terms) as bar:
 
         for hpo_info in bar:
             hpo_bulk.append(build_hpo_term(hpo_info))
