@@ -634,10 +634,17 @@ def events(institute_id, case_name, event_id=None):
     content = request.form.get("content")
     variant_id = request.args.get("variant_id")
     user_obj = store.user(current_user.email)
-
     if event_id:
-        # delete the event
-        store.delete_event(event_id)
+        if "remove" in request.form:
+            # delete the event
+            store.delete_event(event_id)
+        elif "edit" in request.form:
+            # edit comment
+            store.update_comment(
+                comment_id=event_id,
+                new_content=request.form.get("updatedContent"),
+                level=request.form.get("level", "specific"),
+            )
     else:
         if variant_id:
             # create a variant comment
@@ -858,6 +865,17 @@ def delivery_report(institute_id, case_name):
     return send_from_directory(out_dir, filename)
 
 
+@cases_bp.route("/<institute_id>/<case_name>/cnv-report")
+def cnv_report(institute_id, case_name):
+    """Display CNV report."""
+    data = controllers.multiqc(store, institute_id, case_name)
+    if data["case"].get("cnv_report") is None:
+        return abort(404)
+    out_dir = os.path.abspath(os.path.dirname(data["case"]["cnv_report"]))
+    filename = os.path.basename(data["case"]["cnv_report"])
+    return send_from_directory(out_dir, filename)
+
+
 @cases_bp.route("/<institute_id>/<case_name>/share", methods=["POST"])
 def share(institute_id, case_name):
     """Share a case with a different institute."""
