@@ -14,7 +14,5 @@ def omim_entry(store, omim_nr):
 
     omim_obj = store.disease_term(disease_identifier=omim_nr)
     omim_obj["genes_complete"] = store.omim_to_genes(omim_obj)
-    omim_obj["hpo_complete"] = [
-        store.hpo_term(hpo_id) for hpo_id in omim_obj.get("hpo_terms", [])
-    ]
+    omim_obj["hpo_complete"] = [store.hpo_term(hpo_id) for hpo_id in omim_obj.get("hpo_terms", [])]
     return omim_obj
