@@ -5,15 +5,13 @@ import datetime
 def match_date(date):
     """Check if a string is a valid date
 
-        Args:
-            date(str)
+    Args:
+        date(str)
 
-        Returns:
-            bool
+    Returns:
+        bool
     """
-    date_pattern = re.compile(
-        "^(19|20)\d\d[- /.](0[1-9]|1[012])[- /.](0[1-9]|[12][0-9]|3[01])"
-    )
+    date_pattern = re.compile("^(19|20)\d\d[- /.](0[1-9]|1[012])[- /.](0[1-9]|[12][0-9]|3[01])")
     if re.match(date_pattern, date):
         return True
 
@@ -23,15 +21,15 @@ def match_date(date):
 def get_date(date, date_format=None):
     """Return a datetime object if there is a valid date
 
-        Raise exception if date is not valid
-        Return todays date if no date where added
+    Raise exception if date is not valid
+    Return todays date if no date where added
 
-        Args:
-            date(str)
-            date_format(str)
+    Args:
+        date(str)
+        date_format(str)
 
-        Returns:
-            date_obj(datetime.datetime)
+    Returns:
+        date_obj(datetime.datetime)
     """
     date_obj = datetime.datetime.now()
     if date:
