@@ -34,92 +34,62 @@ def test_build_query(adapter):
     assert query["variant_type"] == "clinical"
 
 
-def test_panel_query(real_populated_database, case_obj, variant_objs):
-    """Test variants query using a gene panel, an HPO panel and gene panel + HPO panel"""
+def test_gene_symbols_query(adapter, case_obj, variant_objs):
+    """Test variants query using HGNC symbol"""
 
-    adapter = real_populated_database
-
-    # Test HPO panel query
-    ## HPO panels works differently from normal gene panels:
-    ## the list of genes from the HPO panel is built interactively
-    ## and provided as such to the query builder function.
-    hpo_term = dict(
-        _id="HP1", hpo_id="HP1", description="First term", genes=[17284]  # POT1 gene
-    )
-    adapter.load_hpo_term(hpo_term)
-    assert sum(1 for i in adapter.hpo_term_collection.find()) == 1
-
-    # no variants in database
-    assert sum(1 for i in adapter.variant_collection.find()) == 0
-    # add snv variants to database
-    for variant_obj in variant_objs:
-        adapter.load_variant(variant_obj)
-
-    # grab a variant and add the above gene to it:
-    adapter.variant_collection.find_one_and_update(
-        {"_id": "4c7d5c70d955875504db72ef8e1abe77"},
-        {
-            "$set": {
-                "genes": [{"hgnc_id": 17284}],
-                "hgnc_ids": [17284],
-                "hgnc_symbols": ["POT1"],
-            }
-        },
-    )
-    # test generate HPO gene list for the above term
-    hpo_genes = adapter.generate_hpo_gene_list(*["HP1"])
-    assert hpo_genes
-
-    # Test query by hpo panel
-    query = {"gene_panels": ["hpo"], "hgnc_symbols": ["POT1"]}
-    # Test build panel query:
+    # WHEN hgnc_symbols params is provided to the query builder
+    test_gene = "POT1"
+    query = {"hgnc_symbols": [test_gene], "gene_panels": []}
     mongo_query = adapter.build_query(case_obj["_id"], query=query)
-    # expected query fields should be found in query object
-    assert mongo_query["case_id"] == case_obj["_id"]
-    assert mongo_query["category"] == "snv"
-    assert mongo_query["variant_type"] == "clinical"
-    # gene panel filter part of the query should look like this:
-    # '$and': [{'$or': [{'hgnc_symbols': {'$in': ['POT1']}}, {'panels': {'$in': ['hpo']}}]}]
-    gene_filters = mongo_query["$and"][0]["$or"]
-    assert {"hgnc_symbols": {"$in": ["POT1"]}} in gene_filters
 
-    # Use query on variant data
-    hpo_filtered_vars = list(
-        adapter.variants(case_obj["_id"], query=query, nr_of_variants=-1)
-    )
-    assert len(hpo_filtered_vars) == 1
+    # THEN the query should countain the gene
+    assert mongo_query == {
+        "case_id": case_obj["_id"],
+        "category": "snv",
+        "variant_type": "clinical",
+        "hgnc_symbols": {"$in": [test_gene]},
+    }
 
-    # Test query for a gene panel (not HPO-based)
-    # get 5 variants and label them as belonging to a panel 'test_panel':
-    test_vars = list(adapter.variant_collection.find().limit(5))
-    for test_var in test_vars:
-        adapter.variant_collection.find_one_and_update(
-            {"_id": test_var["_id"]}, {"$set": {"panels": ["test_panel"]}}
-        )
-    # test query by panel:
-    query = {"gene_panels": ["test_panel"]}
-    # Test build panel query:
+
+def test_gene_panel_query(adapter, case_obj, variant_objs):
+    """Test variants query using a gene panel cointaining a certain gene"""
+
+    # GIVEN a database containing a minimal gene panel
+    test_gene = "POT1"
+    test_panel = dict(panel_name="POT panel", version=1, genes=[{"symbol": test_gene}])
+    adapter.panel_collection.insert_one(test_panel)
+    ínserted_panel = adapter.panel_collection.find_one()
+
+    # WHEN the panel _id is provided to the query builder
+    query = {"hgnc_symbols": [], "gene_panels": ["POT panel"]}
     mongo_query = adapter.build_query(case_obj["_id"], query=query)
-    # expected query fields should be found in query object
-    assert mongo_query["case_id"] == case_obj["_id"]
-    assert mongo_query["category"] == "snv"
-    assert mongo_query["variant_type"] == "clinical"
-    assert mongo_query["panels"] == {"$in": ["test_panel"]}
 
-    # Use panel query to get variants occurring in genes from test_panel:
-    test_panel_vars = list(
-        adapter.variants(case_obj["_id"], query=query, nr_of_variants=-1)
-    )
-    # The 5 variants should be returned as a query result
-    assert len(test_panel_vars) == 5
+    # THEN the query should countain the gene(s) of the gene panel
+    assert mongo_query == {
+        "case_id": case_obj["_id"],
+        "category": "snv",
+        "variant_type": "clinical",
+        "hgnc_symbols": {"$in": [test_gene]},
+    }
 
-    # Test combine the 2 panels: hpo panel and test_panel
-    query = {"gene_panels": ["test_panel", "hpo"], "hgnc_symbols": ["POT1"]}
-    combined_panels_vars = list(
-        adapter.variants(case_obj["_id"], query=query, nr_of_variants=-1)
-    )
-    # 5 (test panel) + 1 (hpo panel) variants should be returned
-    assert len(combined_panels_vars) == 6
+
+def test_gene_symbol_gene_panel_query(adapter, case_obj, variant_obj):
+    """Test variants query using a gene panel cointaining a certain gene and a hgnc symbol of another gene"""
+
+    # GIVEN a database containing a minimal gene panel
+    test_gene = "POT1"
+    test_panel = dict(panel_name="POT panel", version=1, genes=[{"symbol": test_gene}])
+    adapter.panel_collection.insert_one(test_panel)
+    ínserted_panel = adapter.panel_collection.find_one()
+
+    # WHEN the panel _id is provided to the query builder + a gene symbol for another gene
+    query = {"hgnc_symbols": ["ATM"], "gene_panels": ["POT panel"]}
+    mongo_query = adapter.build_query(case_obj["_id"], query=query)
+
+    # THEN the query should countain both genes in the hgnc_symbols list
+    mongo_query_gene_list = mongo_query["hgnc_symbols"]["$in"]
+    for gene in ["ATM", "POT1"]:
+        assert gene in mongo_query_gene_list
 
 
 def test_build_gnomad_query(adapter):
@@ -286,9 +256,7 @@ def test_build_clinsig_filter(real_variant_database):
     assert a_variant["_id"]
 
     # there should be no variant with clnsig.value=='Pathogenic, Likely pathogenic'
-    res = adapter.variant_collection.find(
-        {"clnsig.value": "Pathogenic, Likely pathogenic"}
-    )
+    res = adapter.variant_collection.find({"clnsig.value": "Pathogenic, Likely pathogenic"})
     assert sum(1 for i in res) == 0
 
     # Modify clnsig value of this variant to 'Pathogenic, Likely pathogenic'
@@ -298,9 +266,7 @@ def test_build_clinsig_filter(real_variant_database):
     )
 
     # One variant has multiple clssig now:
-    res = adapter.variant_collection.find(
-        {"clnsig.value": "Pathogenic, Likely pathogenic"}
-    )
+    res = adapter.variant_collection.find({"clnsig.value": "Pathogenic, Likely pathogenic"})
     assert sum(1 for i in res) == 1
 
     # Update raw query to find this variant as well
@@ -396,9 +362,7 @@ def test_build_clinsig_always(real_variant_database):
     assert sum(1 for i in res)
 
     # filter variants using query:
-    filtered_variants = list(
-        adapter.variants(case_id=case_id, nr_of_variants=-1, query=query)
-    )
+    filtered_variants = list(adapter.variants(case_id=case_id, nr_of_variants=-1, query=query))
     assert len(filtered_variants) > 0
 
     # Make sure that variants are filtered as they should:
