@@ -19,17 +19,13 @@ def test_variant(real_variant_database, variant_objs, case_obj):
     assert variant_a
 
     # try to collect the variant from database using its document_id and case id:
-    variant_b = adapter.variant(
-        document_id=test_variant["variant_id"], case_id=case_obj["_id"]
-    )
+    variant_b = adapter.variant(document_id=test_variant["variant_id"], case_id=case_obj["_id"])
     assert variant_b
     # it should be the same variant as before:
     assert variant_a == variant_b
 
     # try to collect the variant from database using its case id and simple_id:
-    variant_c = adapter.variant(
-        simple_id=test_variant["simple_id"], case_id=case_obj["_id"]
-    )
+    variant_c = adapter.variant(simple_id=test_variant["simple_id"], case_id=case_obj["_id"])
     assert variant_c
     # it should be the same as the other 2 variants:
     assert variant_c == variant_a
@@ -89,7 +85,6 @@ def test_load_variants(real_populated_database, variant_objs, case_obj):
     # WHEN adding a number of variants
     index = 0
     for index, variant_obj in enumerate(variant_objs):
-        # print(variant_obj)
         adapter.load_variant(variant_obj)
 
     # THEN the same number of variants should have been loaded
@@ -309,3 +304,31 @@ def test_variant_non_existing(adapter):
 
     # THEN that the variant return is None
     assert res is None
+
+
+def test_case_variants_count(real_populated_database, case_obj, institute_obj, variant_objs):
+    """Test the functions that counts the variants by category for a case"""
+
+    # GIVEN a database
+    adapter = real_populated_database
+    case_id = case_obj["_id"]
+    institute_id = institute_obj["_id"]
+
+    # Containing clinical variants
+    nr_clinical = adapter.load_variants(
+        case_obj=case_obj, variant_type="clinical", category="snv", rank_threshold=None
+    )
+    assert nr_clinical > 0
+
+    # And research variants
+    nr_research = adapter.load_variants(
+        case_obj=case_obj, variant_type="research", category="sv", rank_threshold=None
+    )
+    assert nr_research > 0
+
+    # WHEN the function that counts the variants by category is called
+    vars_by_type = adapter.case_variants_count(case_id, institute_id)
+
+    # THEN it should return the expected result
+    assert vars_by_type["clinical"]["snv"] == nr_clinical
+    assert vars_by_type["research"]["sv"] == nr_research
