@@ -484,6 +484,35 @@ def institute_obj(request, parsed_institute):
     return institute
 
 
+#############################################################
+################# Managed variant fixtures ##################
+#############################################################
+
+
+@pytest.fixture(scope="function")
+def managed_variants_lines(request):
+    managed_variants_lines = [
+        "##my_csv_file",
+        "#chromosome;position;end;reference;alternative;category;sub_category;description\n",
+        "14;76548781;76548781;CTGGACC;G;snv;indel;IFT43 indel test\n",
+        "17;48696925;48696925;G;T;snv;snv;CACNA1G intronic test\n",
+        "7;124491972;124491972;C;A;snv;snv;POT1 test snv\n",
+    ]
+    return managed_variants_lines
+
+
+@pytest.fixture(scope="function")
+def managed_variants_first_line_header(request):
+    managed_variants_lines = [
+        "chromosome;position;end;reference;alternative;category;sub_category;description\n",
+        "14;76548781;76548781;CTGGACC;G;snv;indel;IFT43 indel test\n",
+        "17;48696925;48696925;G;T;snv;snv;CACNA1G intronic test\n",
+        ";;;;;;;\n",
+        "7;124491972;124491972;C;A;snv;snv;POT1 test snv\n",
+    ]
+    return managed_variants_lines
+
+
 #############################################################
 ##################### User fixtures #########################
 #############################################################
